summaryrefslogtreecommitdiff
path: root/lib/mac-learning.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/mac-learning.h')
-rw-r--r--lib/mac-learning.h9
1 files changed, 3 insertions, 6 deletions
diff --git a/lib/mac-learning.h b/lib/mac-learning.h
index d9fa433cd..d2f28744f 100644
--- a/lib/mac-learning.h
+++ b/lib/mac-learning.h
@@ -18,15 +18,12 @@
#define MAC_LEARNING_H 1
#include <time.h>
+#include "hmap.h"
#include "list.h"
#include "packets.h"
#include "tag.h"
#include "timeval.h"
-#define MAC_HASH_BITS 10
-#define MAC_HASH_MASK (MAC_HASH_SIZE - 1)
-#define MAC_HASH_SIZE (1u << MAC_HASH_BITS)
-
#define MAC_MAX 2048
/* Time, in seconds, before expiring a mac_entry due to inactivity. */
@@ -38,7 +35,7 @@
/* A MAC learning table entry. */
struct mac_entry {
- struct list hash_node; /* Element in a mac_learning 'table' list. */
+ struct hmap_node hmap_node; /* Node in a mac_learning hmap. */
struct list lru_node; /* Element in 'lrus' or 'free' list. */
time_t expires; /* Expiration time. */
time_t grat_arp_lock; /* Gratuitous ARP lock expiration time. */
@@ -78,10 +75,10 @@ static inline bool mac_entry_is_grat_arp_locked(const struct mac_entry *mac)
/* MAC learning table. */
struct mac_learning {
+ struct hmap table; /* Learning table. */
struct list free; /* Not-in-use entries. */
struct list lrus; /* In-use entries, least recently used at the
front, most recently used at the back. */
- struct list table[MAC_HASH_SIZE]; /* Hash table. */
struct mac_entry entries[MAC_MAX]; /* All entries. */
uint32_t secret; /* Secret for randomizing hash table. */
unsigned long *flood_vlans; /* Bitmap of learning disabled VLANs. */